# IdentityAssertion

A raw token and set of options for how to introspect the token
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authentication_document_id** | **str** | the authentication document ID representing the authentication document that generated this identity assertion. | 
**token** | **str** | A JSON Web Token containing the identity assertion. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


